@@ -890,7 +890,7 @@ class ProjectService_0_7(BaseVersion):
                 'coord_frame': exp.coord_frame,
                 'num_hierarchy_levels': exp.num_hierarchy_levels,
                 'hierarchy_method': exp.hierarchy_method,
-                'num_time_samples': exp.num_time_samples,
+                'max_time_sample': exp.max_time_sample,
                 'collection': exp.coll_name
             }
 
@@ -898,7 +898,8 @@ class ProjectService_0_7(BaseVersion):
             'name': exp.name,
             'description': exp.description ,
             'num_hierarchy_levels': exp.num_hierarchy_levels,
-            'hierarchy_method': exp.hierarchy_method
+            'hierarchy_method': exp.hierarchy_method,
+            'max_time_sample': exp.max_time_sample
         }
 
     def _get_coordinate_params(self, coord, for_update):
@@ -927,7 +928,7 @@ class ProjectService_0_7(BaseVersion):
             return {
                 'name': chan.name,
                 'description': chan.description ,
-                'default_time_sample': chan.default_time_sample,
+                'default_time_step': chan.default_time_step,
                 'datatype': chan.datatype,
                 'base_resolution': chan.base_resolution,
                 'type': chan.type,
@@ -939,6 +940,7 @@ class ProjectService_0_7(BaseVersion):
             'name': chan.name,
             'description': chan.description,
             'base_resolution': chan.base_resolution,
+            'default_time_step': chan.default_time_step,
             'sources': chan.sources,
             'related': chan.related
         }
@@ -980,7 +982,7 @@ class ProjectService_0_7(BaseVersion):
     def _get_experiment(self, dict, coll_name):
         exp_keys = [
             'name', 'description', 'creator', 'coord_frame',
-            'num_hierarchy_levels', 'hierarchy_method', 'num_time_samples'
+            'num_hierarchy_levels', 'hierarchy_method', 'max_time_sample'
         ]
 
         filtered = { k:v for (k, v) in dict.items() if k in exp_keys }
@@ -1000,7 +1002,7 @@ class ProjectService_0_7(BaseVersion):
 
     def _get_channel(self, dict, coll_name, exp_name):
         chan_keys = [
-            'name', 'description', 'creator', 'default_time_sample',
+            'name', 'description', 'creator', 'default_time_step',
             'datatype', 'base_resolution', 'type', 'sources', 'related'
         ]
 
